import re
from helpers.BasicComicModule import BasicComicModule

class EternalVenture(BasicComicModule):
    latestUrl = 'http://pulledpunches.com/index2.php'
    imageUrl = 'http://pulledpunches.com/archive.php?date=%s.jpg'
    imageSearch = re.compile(r'<img src="(buzzNav/comics/\d{8}\..+?)"', re.IGNORECASE)
    prevSearch = re.compile(r'</a></td>[^>].*<td>[^>].+?<a href="(.*?date=.+?)".*?previous', re.IGNORECASE)
    help = 'Index format: yyyymmdd'
